@@ -9,10 +9,12 @@ This is the complete API reference:
 .. autosummary::
    :toctree: .
 
+   EFO
    readout
+   lookup
 """
 
-__version__ = "0.1.2"
+__version__ = "0.2.0"
 
-from . import lookup  # noqa
-from ._efo import EFO, readout  # noqa
+from ._efo import EFO, readout
+from ._lookup import lookup
